@@ -5,7 +5,7 @@
 
 use std::collections::HashMap;
 
-use dbfile::DBfile;
+
 use regex::{Regex, Captures};
 use select::{document::Document, predicate::{Name, Predicate, Attr, Any}, node::Node};
 use crate::value::Value;
@@ -60,8 +60,12 @@ impl<'a> Parser<'a> {
             self.document.find(Name(&caps[1]).descendant(Name(&caps[2]))).map(|n|n).collect::<Vec<Node>>()
         }));
         self.css_process.insert(r"\[([\w-]+)~([\w-]+)\]", Box::new(|caps| {
+            let reg = Regex::new(&caps[2]).unwrap();
+
             self.document.find(Any)
-            .filter(|n| n.attr(&caps[1]).map_or(false, |v| v.contains(&caps[2])))
+            .filter(|n| n.attr(&caps[1]).map_or(
+                false, |v| reg.is_match(v))
+            )
             .collect::<Vec<Node>>()
         }));
 
@@ -76,6 +80,16 @@ impl<'a> Parser<'a> {
             .collect::<Vec<Node>>()
             
         }));
+
+        self.css_process.insert(r"^([\w-]+)#([\w-]+)\s+([\w-]+)", Box::new(|caps| {
+            // css selector div#id span
+            self.document.find(Name(&caps[1]))
+                .filter(|n| n.attr("id").map_or(false, |v| v == &caps[2]))
+                .collect::<Vec<Node>>()
+                .iter()
+                .map(|n| n.find(Name(&caps[3])).next().unwrap())
+                .collect::<Vec<Node>>()
+        }));
     }
 
     pub fn free_select<F>(&mut self,  selector: &str, mut fn_nodes: F) 
