@@ -12,7 +12,7 @@ fn test_hello() {
     fn test_find_all() {
         let data = Cache::new();
         let client = Requests::new(&data);
-        let mut rq = client.connect("https://www.qq.com/", Headers::Default);
+        let rq = client.connect("https://www.qq.com/", Headers::Default);
 
         rq.parser(|p| {
             p.find_all("a", |x| {
@@ -28,4 +28,4 @@ fn test_hello() {
 
         data.print();
        
-    }
\ No newline at end of file
+    }
